require "reelagram/version"
require "reelagram/errors"
require "reelagram/mail/parsers"
require "reelagram/mail/processors"
require "reelagram/mail/fetchers"
require "reelagram/mail/configuration"

module Reelagram
  module Mail
    class << self
      attr_accessor :configuration
    end

    def self.configure
      self.configuration ||= Configuration.new
      yield(configuration)
      configured?
    end

    def self.configured?
      return false if configuration.nil?
      configuration.configured?
    end

    def self.process_shipping_emails
      emails = Fetchers::ShippingFetcher.new.fetch
      parser = Parsers::ShippingParser.new
      Processors::ShippingProcessor.new(emails, parser).run
    end

    def self.debug?
      false unless configured?
      configuration.debug
    end
  end
end
