require "nokogiri"

module Reelagram
  module Mail
    module Parsers
      class ShippingParser
        attr_reader :doc, :debug

        def initialize
          @debug = Reelagram::Mail.debug?
        end

        def run(string)
          @doc = Nokogiri::HTML(string)
          log_parsed_data if debug
          self
        end

        def carrier
          return "Unavailable" unless shipping_info_row
          @row.children[0].text
        end

        def tracking_number
          return "Unavailable" unless shipping_info_row
          tracking_link_container.text
        end

        def tracking_link
          return unless shipping_info_row
          begin
            tracking_link_container.css("a")
              .attr("href")
              .value
          rescue
            nil
          end
        end

        def order_number
          return unless table = doc.css("table")[2]
          table.css("tr")
            .children.css("td")
            .children
            .text
            .gsub(/\\n+/, " ")
            .scan(/\w*/)
            .reject(&:empty?)
            .last
        end

        def reset!
          @shipping_info_table, @row = nil, nil
        end

        private

        def tracking_link_container
          @row.children[2].css("a")
        end

        def shipping_info_table
          @shipping_info_table ||= doc.css("table")[-2]
        end

        def shipping_info_row
          if shipping_info_table
            @row ||= @shipping_info_table.css("tr")[-1]
          end
        end

        def log_parsed_data
          log("-------------------------------------")
          log("Order Number:    #{order_number}")
          log("Carrier:         #{carrier}")
          log("Tracking Number: #{tracking_number}")
          log("Tracking Link:   #{tracking_link}")
          log("-------------------------------------")
        end

        def log(message)
          STDOUT.puts(message)
        end
      end
    end
  end
end
